import debounce from 'lodash/debounce';
import Player from '@vimeo/player';
import PropTypes from 'prop-types';
import React from 'react';

class App extends React.Component {
  static get propTypes() {
    return {
      id: PropTypes.string.isRequired,
      ratio: PropTypes.number,
    };
  }

  static get defaultProps() {
    return {
      ratio: 0.561,
    };
  }

  constructor(props) {
    super(props);

    this.initResize = this.initResize.bind(this);
    this.resize = this.resize.bind(this);
  }

  componentDidMount() {
    this.player = new Player(this.container, {
      id: this.props.id,
      byline: false,
      portrait: false,
      title: false,
    });

    this.player.on('loaded', this.initResize);
  }

  initResize() {
    this.iframe = this.container.querySelector('iframe');

    this.resize();

    window.addEventListener('resize', debounce(this.resize, 100));
  }

  resize() {
    const height = this.iframe.clientWidth * this.props.ratio;
    this.iframe.style.height = `${height}px`;
  }

  render() {
    return (
      <div
        ref={(container) => {
          this.container = container;
        }}
      />
    );
  }
}

export default App;
